import json
import pdb
import multiprocessing
from multiprocessing.pool import ThreadPool

from shopping_utils.google_shopping import GoogleShopping

from em_tasks import logger
from em_tasks.shopify.product_util import ProductUtil
from em_tasks.store.store_util import StoreUtil
from em_tasks.utils.shopify_base_repricer import ShopifyBaseRepricer
from em_tasks.store.models import *


class ShopifyDangdangRepricer(ShopifyBaseRepricer):
  def __init__(self, store_code):
    self.condition = 'new'

    self.store = StoreUtil.get_store_by_code(store_code)
    if not self.store:
      return

    credential = json.loads(self.store.api_credential)
    self.product_util = ProductUtil(credential['name'], credential['token'], credential.get('release', None))
    self.pool = ThreadPool(3)

    self.gss = dict()
    gmc_stores = GmcStore.select().execute()
    for gmc_store in gmc_stores:
      self.gss[gmc_store.id] = GoogleShopping(
        gmc_store.merchant_id, json.loads(gmc_store.service_account_data))

  def run(self):
    batch_size = 250
    prods = dict()
    for dangdang_prod in StoreUtil.get_dangdang_products():
      prods[dangdang_prod['product_id']] = dangdang_prod
      if len(prods) < batch_size:
        continue

      self.process_products(prods)
      prods.clear()

    if prods:
      self.process_products(prods)
      prods.clear()

    self.pool.close()
    self.pool.join()

  def process_products(self, prods):
    sps = self.product_util.get_products(list(prods.keys()))
    for product_id, prod in prods.items():
      if product_id not in sps:
        continue

      sp = sps[product_id]
      v = sp.variants[0]
      prod['offer'] = {'price': round(float(v.price) + 7, 2), 'quantity': 50}

    store_offers = self.product_util.set_products_offer(prods, self.pool)
    try:
      self.update_gmc_offers(store_offers)
    except Exception as e:
      logger.exception(e)

